@@ -20,8 +20,8 @@ public:
   virtual ~Surface();
 
   //-- SFCGAL::Geometry
-  virtual int
-  dimension() const;
+  int
+  dimension() const override;
 
   /**
    * [OGC/SFS]"The area of this Surface, as measured in the spatial reference
