@@ -15,15 +15,13 @@ namespace detail {
 /**
  * lexicographic order on complex
  */
-struct SFCGAL_API ComplexComparator {
-  template <typename T>
-  inline bool
-  operator()(const std::complex<T> &a, const std::complex<T> &b) const
-  {
-    return (a.real() < b.real()) ||
-           (a.real() == b.real() && a.imag() < b.imag());
-  }
-};
+struct SFCGAL_API ComplexComparator{
+    template <typename T> inline bool operator()(const std::complex<T> &a,
+                                                 const std::complex<T> &b)
+        const {return (a.real() < b.real()) ||
+                      (a.real() == b.real() && a.imag() < b.imag());
+} // namespace detail
+}; // namespace SFCGAL
 
 } // namespace detail
 } // namespace SFCGAL
