@@ -21,8 +21,8 @@ public:
   /*
    * [SFCGAL::Transform]
    */
-  virtual void
-  transform(Point &p);
+  void
+  transform(Point &p) override;
 };
 
 } // namespace transform
